@@ -1,4 +1,4 @@
-import { contextSrv } from 'app/core/core';
+import { contextSrv } from 'app/core/services/context_srv';
 import { SavedQuery } from 'app/features/explore/QueryLibrary/types';
 
 import { newestSortingOption } from '../QueryLibrarySortingOptions';
@@ -7,7 +7,7 @@ import { QueryLibraryTab } from '../types';
 import { searchQueryLibrary } from './search';
 
 // Mock contextSrv
-jest.mock('app/core/core', () => ({
+jest.mock('app/core/services/context_srv', () => ({
   contextSrv: {
     user: {
       uid: 'user123',
